<?php
// +-----------------------------------------------------------------------------+
// | smilies for Geeklog                                                         |
// | Date: Nov, 2007                                                             |
// +-----------------------------------------------------------------------------+
// | functions.inc - Geeklog Plugin API functions and support functions          |
// +-----------------------------------------------------------------------------+
// | Copyright (C) 2007 by:                                                      |
// | smilies Plugin Author:                                                      |
// | Alford Deeley - ajdeeley@summitpages.ca                                     |
// +-----------------------------------------------------------------------------+
// | Geeklog Common Code                                                         |
// | Copyright (C) 2000-2007 by the following authors:                           |
// | Authors: Tony Bibbs        - tony@tonybibbs.com                             |
// |          Mark Limburg      - mlimburg@users.sourceforge.net                 |
// |          Jason Whittenburg - jwhitten@securitygeeks.com                     |
// |          Dirk Haun         - dirk@haun-online.de                            |
// +-----------------------------------------------------------------------------+
// |                                                                             |
// | This program is licensed under the terms of the GNU General Public License  |
// | as published by the Free Software Foundation; either version 2              |
// | of the License, or (at your option) any later version.                      |
// |                                                                             |
// | This program is distributed in the hope that it will be useful,             |
// | but WITHOUT ANY WARRANTY; without even the implied warranty of              |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.                        |
// | See the GNU General Public License for more details.                        |
// |                                                                             |
// | You should have received a copy of the GNU General Public License           |
// | along with this program; if not, write to the Free Software Foundation,     |
// | Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             |
// |                                                                             |
// +-----------------------------------------------------------------------------+

require_once ($_CONF['path'] . 'plugins/smilies/config.php');

$langfile = $_CONF['path'] . 'plugins/smilies/language/' . $_CONF['language'] . '.php';
if (file_exists ($langfile)) {
    require_once ($langfile);
}
else {
    require_once ($_CONF['path'] . 'plugins/smilies/language/english.php');
}

function plugin_chkVersion_smilies() {
    global $CONF_smilies; 
    return $CONF_smilies['version'];
}

/**
* Removes the data structures for this plugin from the Geeklog database
*
* This may get called by the install routine to undo anything done to this
* point.  To do that, $steps will have a list of steps to undo
*
* @steps   Array    Holds all the steps that have been completed by the install
*
*/
function plugin_uninstall_smilies()
{
    global $_TABLES;
    $FEATURES = array ('smilies.admin', 'smilies.add');
    $TABLES = array ('smilies_data','smilies_settings','smilies_submissions');

    // Unregister the plugin with Geeklog
    COM_errorLog('Attempting to unregister the smilies plugin from Geeklog',1);
    DB_query("DELETE FROM {$_TABLES['plugins']} WHERE pi_name = 'smilies'",1);
    
    // Drop Plugun tables
    foreach($TABLES as $table) {
        $t = $_TABLES["$table"];
        COM_errorLog("Removing Table $t",1);
        DB_query("DROP TABLE $t",1);
    }

    // Remove security for this plugin

    $grp_id = DB_getItem($_TABLES['groups'], 'grp_id', "grp_name = 'smilies Admin'");
    
    // Remove the smilies admin group
    COM_errorLog('Attempting to remove the smilies Admin Group', 1);
    DB_query("DELETE FROM {$_TABLES['groups']} WHERE grp_id = $grp_id");
    
    // Remove root users from the group
    COM_errorLog('Attempting to remove root users from admin of smilies');
    DB_query("DELETE FROM {$_TABLES['group_assignments']} WHERE ug_main_grp_id = $grp_id");

    // Remove all the associated features - access rights.
    foreach ($FEATURES as $feature) {
        COM_errorLog("Removing $feature feature and rights to it",1);
        $feat_id = DB_getItem($_TABLES['features'], 'ft_id', "ft_name = '$feature'");
        DB_query("DELETE FROM {$_TABLES['access']} WHERE acc_ft_id = $feat_id",1);
        DB_query("DELETE FROM {$_TABLES['features']} WHERE ft_id = $feat_id",1);
    }
    
    COM_errorLog('...success',1);
    COM_errorLog('leaving plugin_uninstall_smilies',1);

    return true;
}

function plugin_upgrade_smilies(){
    global $_CONF, $_TABLES, $CONF_smilies;
    
    $pi_name = 'smilies';
    $version = DB_getItem($_TABLES['plugins'], 'pi_version', "pi_name = '$pi_name'");
    
    if ($version < '1.1') {
        //upgrade from initial release
        DB_query("UPDATE {$_TABLES['plugins']} SET pi_version = '{$CONF_smilies['version']}' WHERE pi_name = '$pi_name'");
    }
    
    if ($version < '1.2') {
        //upgrade to version 1.2
        DB_query("UPDATE {$_TABLES['plugins']} SET pi_version = '{$CONF_smilies['version']}' WHERE pi_name = '$pi_name'");
    }
    
    return true;
}

function plugin_cclabel_smilies() {
    global $_CONF,$LANG_SMILIES00;
    if (SEC_hasRights('smilies.admin')) {
        return array($LANG_SMILIES00[1],$_CONF['site_admin_url'] . "/plugins/smilies/index.php",$_CONF['site_url'] . '/smilies/images/smilies.png');
    }
}

function plugin_getadminoption_smilies() {
    global $_TABLES,$_CONF,$LANG_SMILIES00;

    if (SEC_hasRights('smilies.admin')) {
        $numsmilies = DB_getITEM($_TABLES['smilies_data'],"count(*)");
        return array($LANG_SMILIES00[1], $_CONF['site_admin_url'] . '/plugins/smilies/index.php', $numsmilies);
    }
}

function plugin_getuseroption_smilies() {
    global $_CONF, $_TABLES, $LANG_SMILIES00;

    $enabled_useradd = DB_getItem($_TABLES['smilies_settings'], 'enabled_useradd');
    if ($enabled_useradd == '1' || SEC_hasRights('smilies.admin') || SEC_hasRights('smilies.add')) {
        return array($LANG_SMILIES00[2], $_CONF['site_url'] . '/smilies/index.php?op=list', 0);
    }
}

function plugin_autotags_smilies($op, $content = '', $autotag = '') {
    global $_CONF, $_TABLES;
    
    if ($op == 'tagname') {
        return 'smiley';
    } elseif (DB_getItem($_TABLES['smilies_settings'], 'disabled_autotags') == '1') {
        $link = '';
    } elseif ($op == 'parse') {
        $code = addslashes (strip_tags($autotag['parm1']));
        $result = DB_query("SELECT filename, description FROM {$_TABLES['smilies_data']} WHERE code ='$code' AND enabled = '1'");
        
        if (DB_numRows($result) < 1) {
            $link = '';
        } else {
            list($filename,$description) = DB_fetchArray($result);
            
            $link = '<img src="' . $_CONF['site_url']
                . '/smilies/smileyfiles/'
                . COM_stripslashes($filename)
                . '" alt="' . COM_stripslashes($description)
                . '" title="' . COM_stripslashes($description)
                . '" border="0" style="vertical-align:bottom;">';
        }
    }
    
    $content = str_replace($autotag['tagstr'], $link, $content);
    return $content;
}

function plugin_geticon_smilies() {
    global $_CONF;
    
    return $_CONF['site_url'] . '/smilies/images/smilies.png';
}

//any smilies belonging to a user being deleted will
//become the root user's smilies.
function plugin_user_delete_smilies($uid) {
    global $_TABLES;
    
    DB_query("UPDATE {$_TABLES['smilies_data']} SET
        owner_id = '2'
        WHERE owner_id = '$uid'");
}

function plugin_submissioncount_smilies() {
    global $_TABLES;
    
    $result = DB_query("SELECT COUNT(*) as count FROM {$_TABLES['smilies_submissions']}");
    list($count) = DB_fetchArray($result);
    
    return $count;
}

function plugin_moderationapprove_smilies($id) {
    global $_TABLES, $CONF_smilies, $_CONF;
    
    //enable smiley
    $result = DB_query("UPDATE {$_TABLES['smilies_data']} SET enabled = '1' WHERE id = '$id'");
    //move file
    foreach ($CONF_smilies['allowed_ext'] as $ext) {
        $oldname = $_CONF['path_html'] . 'smilies/submissions/' . $id . '.' . $ext;
        $newname = $_CONF['path_html'] . 'smilies/smileyfiles/' . $id . '.' . $ext;
        if (is_file($oldname)) {
            if (!@rename($oldname, $newname)) {
                COM_errorLog("Attempt to move smiley file, $oldname, to approved files directory failed.",1);
            }
        }
    }
}

function plugin_moderationdelete_smilies($id) {
    global $_CONF, $_TABLES, $CONF_smilies;
    
    //delete file from disk
    foreach ($CONF_smilies['allowed_ext'] as $ext) {
        $filename = $_CONF['path_html'] . 'smilies/submissions/' . $id . '.' . $ext;
        if (is_file($filename)) {
            if (@!unlink($filename)) {
                COM_errorLog("Attempt to delete smiley file, $filename, from disk failed.",1);
            }
        }
    }
}

function plugin_moderationvalues_smilies() {
    global $_TABLES;
    
    //oy!
    return array(
        'id',
        $_TABLES['smilies_data'],
        "id, filename, code, description, owner_id, enabled",
        $_TABLES['smilies_submissions']
    );
}

function plugin_ismoderator_smilies() {
    return SEC_hasRights ('smilies.admin');
}

function plugin_itemlist_smilies() {
    global $_TABLES, $LANG_SMILIES00;
    
    if (plugin_ismoderator_smilies()) {
        $plugin = new Plugin();
        $plugin->submissionlabel = $LANG_SMILIES00[6];
        $plugin->getsubmissionssql = "SELECT id,filename,code,owner_id
                            FROM {$_TABLES['smilies_submissions']}
                            ORDER BY id ASC";
        $plugin->addsubmissionheading($LANG_SMILIES00[7]);
        $plugin->addsubmissionheading($LANG_SMILIES00[8]);
        $plugin->addsubmissionheading($LANG_SMILIES00[10]);
        
        return $plugin;
    }
}

function smilies_sendNotification($id, $filename, $code, $description) {
    global $_CONF, $_TABLES, $LANG_SMILIES00;
    
    $id = stripslashes($id);
    $filename = stripslashes ($filename);
    $code = stripslashes($code);
    if (!empty($description)) {
        $description = stripslashes ($description);
    } else {
        $description = $LANG_SMILIES00[15];
    }
    
    $mailsubject = $_CONF['site_name'] . ' ' . $LANG_SMILIES00[16];
    
    $mailbody = "{$LANG_SMILIES00[11]}\n";
    $mailbody .= "{$LANG_SMILIES00[12]} $filename\n";
    $mailbody .= "{$LANG_SMILIES00[13]} $code\n";
    $mailbody .= "{$LANG_SMILIES00[14]} $description\n";
    $mailbody .= "\n{$LANG_SMILIES00[17]} <{$_CONF['site_admin_url']}/moderation.php>\n\n";
    $mailbody .= "\n------------------------------\n";
    $mailbody .= "\n{$LANG_SMILIES00[18]}\n";
    $mailbody .= "\n------------------------------\n";
    
    COM_mail ($_CONF['site_mail'], $mailsubject, $mailbody);
}

?>